import pytest
from orchestrator.types import SubscriptionLifecycle

from gso.products import ProductName
from gso.products.product_types.layer_2_circuit import Layer2Circuit
from test.workflows import assert_complete, run_workflow


@pytest.mark.workflow()
@pytest.mark.parametrize(
    "layer_2_circuit_service_type", [ProductName.IMPORTED_EXPRESSROUTE, ProductName.IMPORTED_GEANT_PLUS]
)
def test_import_layer_2_circuit_success(layer_2_circuit_service_type, layer_2_circuit_subscription_factory):
    imported_layer_2_circuit = layer_2_circuit_subscription_factory(
        layer_2_circuit_service_type=layer_2_circuit_service_type
    )
    result, _, _ = run_workflow(
        "import_layer_2_circuit", [{"subscription_id": imported_layer_2_circuit}]
    )
    subscription = Layer2Circuit.from_subscription(imported_layer_2_circuit)

    assert_complete(result)
    #  Remove the "IMPORTED_" prefix with ``[9:]``
    assert subscription.product.name == layer_2_circuit_service_type.value[9:]
    assert subscription.status == SubscriptionLifecycle.ACTIVE
    assert subscription.insync is True
